% This file is to compare the structural response of a base isolator system
% when a acceleration input is used and vel. and displ. too.


%%
clc, clear, close all
warning off

M = 1;
K = (2*pi)^2;
C = .15;
ndof = length(M);
m_b = 10; 
k_b = K/2;
c_b = 5;
ndofb = 2; 

ndof = length(M);
% BUILD STATE SPACE SYSTEMS (without Base Isolation system)
% Input:   1) GAeration
% Outputs: 1) relative displacement
%          2) relative velocity
%          3) absolute acceleration
AA = [zeros(ndof) eye(ndof);-inv(M)*K -inv(M)*C];
BB = [zeros(ndof,1);-inv(M)*K];
CC = [eye(ndof*2);-inv(M)*K -inv(M)*C];
DD = [zeros(ndof*3,1)];


%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%       Entire Building Information         %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
clc, clear, close all
M  	 = 155.6;					% mass per floor [N/(m/sec2)]
K    = 1.004922e+05;		    % N/m
Zeta = 0.2;
C    = 2*M*Zeta*sqrt(K/M);
wn_T = sqrt(K/M)/(2*pi());
wd_T = wn_T*sqrt(1-Zeta^2);

disp(['Entire Structure Natural Frequency is ' num2str(round(100*wd_T)/100) ' Hz'])
ndof = length(M);
% BUILD STATE SPACE SYSTEMS (without Base Isolation system)
% Input:   1) GAeration
% Outputs: 1) relative displacement
%          2) relative velocity
%          3) absolute acceleration
AA = [zeros(ndof) eye(ndof);-inv(M)*K -inv(M)*C];
BB = [zeros(ndof,1);-inv(M)*K];
CC = [eye(ndof*2);-inv(M)*K -inv(M)*C];
DD = [zeros(ndof*3,1)];

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%        Base Isolation Information         %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

m_b = 10; 
k_b = K/200;
zeta_b = 0.2;
c_b   = 2*m_b*zeta_b*sqrt(K/M);

ndofb = 2; 


%% BUILD MASS, STIFFNESS, DAMPING MATRICES(w/Base Isolator)
MMb = diag([m_b M]);
Cdb = [C+c_b -C;-C C];
KKb = [K+k_b -K;-K K];
PPt = [-m_b;-M];
% BUILD STATE SPACE SYSTEMS (w/Base Isolator)
% Input:   1) Ground Acceleration, [g's] 
% Outputs: 1-2) relative displacement of masses
%          3-4) relative velocity of masses
%          5-6) absolute acceleration of masses
%          7-8) interstory displacement of masses
AA_R = [zeros(ndofb) eye(ndofb);-inv(MMb)*KKb -inv(MMb)*Cdb];
BB_R = [zeros(ndofb,1);-inv(MMb)*PPt];
CC_R = [eye(ndofb*2);-inv(MMb)*KKb -inv(MMb)*Cdb;[1 0 0 0;-1 1 0 0]];
DD_R = [zeros(ndofb*4,1)];

sys_R = ss(AA_R,BB_R,CC_R,DD_R)

%------------------------------------
% RTHS system
% Input:   1) Ground Desplacement, [in]
%          2) Ground Velocity,     [in/sec]
% Outputs: 1-2) Total displacement of masses
%          3-4) Total velocity of masses
%          5-6) Total acceleration of masses 
%           Y_5 := Total acceleration of ISOLATOR
%           Y_6 := Total acceleration of ROOF


% Steel Building (Numerical Substructure)
ndof = 2;
MN = M;
KN = K; 
CN = C;

% Base Isolation (Experimental Substructure)
ME = m_b; 
KE = k_b;
CE = c_b;

AA_RTHS=[zeros(ndof) eye(ndof); -KN/MN KN/MN -CN/MN CN/MN; KN/ME -(KN+KE)/ME CN/ME -(CN+CE)/ME] 
BB_RTHS=[zeros(ndof+1,2); KE/ME CE/ME]
CC_RTHS=[eye(ndof*2); -KN/MN KN/MN -CN/MN CN/MN; KN/ME -(KN+KE)/ME CN/ME -(CN+CE)/ME] 
DD_RTHS=[zeros(ndof*2+1,2); KE/ME CE/ME]

sys_RTHS = ss(AA_RTHS,BB_RTHS,CC_RTHS,DD_RTHS)

g = 9.81;

dtint = 0.02;Tmax = 29.36; 
OPTIONS = simset('solver','ode5','FixedStep',dtint);
sim('bi_sim_compare',[0 Tmax],OPTIONS,[]); 


% %% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% %            FIGURES ans COMPARATION         %
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
load 'quake_des.mat';
load 'quake_vel.mat';
t = des_ground(1,:)';

figure(1)
subplot(3,2,1)
plot(t,-g*yb(:,1),'b-','linewidth',1.5), hold on, grid on
plot(t,RTHS(:,2)-des_ground(2,:)','r--','linewidth',1)
title('EXPERIMENTAL SUBSTRUCTURE','fontweight','bold')
ylabel('Relative des., [m]','FontSize',9,'fontweight','bold')

subplot(3,2,2)
plot(t,-g*yb(:,2),'b-','linewidth',1.5), hold on, grid on
plot(t,RTHS(:,1)-des_ground(2,:)','r--','linewidth',1)
a = legend('w/ accel. input','w/ vel. & dis. inputs'); set(a,'FontSize',8)
title('NUMERICAL SUBSTRUCTURE','fontweight','bold')

subplot(3,2,3)
plot(t,-g*yb(:,3),'b-','linewidth',1.5), hold on, grid on
plot(t,RTHS(:,4)-vel_ground(2,:)','r--','linewidth',1)
ylabel('Relative vel., [m/s]','FontSize',9,'fontweight','bold')

subplot(3,2,4)
plot(t,-g*yb(:,4),'b-','linewidth',1.5), hold on, grid on
plot(t,RTHS(:,3)-vel_ground(2,:)','r--','linewidth',1)

subplot(3,2,5)
plot(t,-g*yb(:,5),'b-','linewidth',1.5), hold on, grid on
plot(t,RTHS(:,6)','r--','linewidth',1)
xlabel('Time, [sec]','FontSize',9,'fontweight','bold')
ylabel('Total accel., [m/s^2]','FontSize',9,'fontweight','bold')

subplot(3,2,6)
plot(t,-g*yb(:,6),'b-','linewidth',1.5), hold on, grid on
plot(t,RTHS(:,5)','r--','linewidth',1)
xlabel('Time, [sec]','FontSize',9,'fontweight','bold')

saveas(gcf,'compare','jpeg')




